==> tdewebdev-trinity_14.0.12.orig.tar.xz: tdewebdev-trinity-14.0.12/config.h.cmake <==
#define VERSION "@VERSION@"

// Defined if you have fvisibility and fvisibility-inlines-hidden support.
#cmakedefine __KDE_HAVE_GCC_VISIBILITY 1

/* Define WORDS_BIGENDIAN to 1 if your processor stores words with the most
   significant byte first (like Motorola and SPARC, unlike Intel). */
#cmakedefine WORDS_BIGENDIAN @WORDS_BIGENDIAN@

/* Define to 1 if you have the <unistd.h> header file. */
#cmakedefine HAVE_UNISTD_H 1

/* Define to 1 if you have the <string.h> header file. */
#cmakedefine HAVE_STRING_H 1

/* Define to 1 if you have the <sys/time.h> header file. */
#cmakedefine HAVE_SYS_TIME_H 1

/* Define to 1 if you have the <sys/stat.h> header file. */
#cmakedefine HAVE_SYS_STAT_H 1

/* Define to 1 if you have the <stdlib.h> header file. */
#cmakedefine HAVE_STDLIB_H 1

/* Define to 1 if you have the <stdarg.h> header file. */
#cmakedefine HAVE_STDARG_H 1

/* Define to 1 if you have the <time.h> header file. */
#cmakedefine HAVE_TIME_H 1

/* Define to 1 if you have the <pthread.h> header file. */
#cmakedefine USE_XSLDBG_AS_THREAD 1

/* Define to 1 if you have the <locale.h> header file. */
//#cmakedefine LOCALE_PREFIX 1

/* Define to 1 if you have the <readline/readline.h> header file. */
#cmakedefine HAVE_READLINE @HAVE_READLINE@

/* Define to 1 if you have the 'gettimeofday' function */
#cmakedefine HAVE_GETTIMEOFDAY 1

/* Define to 1 if you have the 'usleep' function */
#cmakedefine HAVE_USLEEP 1

/* Define to 1 if you have the 'stat' function */
#cmakedefine HAVE_STAT 1

/* Define to 1 if you have the <readline/history.h> header file. */
#cmakedefine HAVE_HISTORY @HAVE_HISTORY@

/* Define the name of the xsldbg executable */
#cmakedefine XSLDBG_BIN "@XSLDBG_BIN@"

/* Defined if you build build for other editors than Kate */
#cmakedefine ENABLE_EDITORS 1

/* Defined if you build with cvsservice */
#cmakedefine ENABLE_CVSSERVICE 1

/* Defined if libxml-2.0 is up to 2.6 */
#cmakedefine LIBXML_2_5 1

/* Defined if you have <libxml/DOCBparser.h> header file */
#cmakedefine LIBXML_DOCB_ENABLED

/* Defined if you have <libxml/xinclude.h> header file */
#cmakedefine LIBXML_XINCLUDE_ENABLED

/* Defined if you have xmlSetEntityReferenceFunc within libxml2 */
#cmakedefine HAVE_INCLUDE_FIX 1

/* Define the kmdr-executor executable path */
#cmakedefine KMDR_EXECUTOR_PATH "@KMDR_EXECUTOR_PATH@"

/* Define TQTDOCDIR PATH */
#cmakedefine TQTDOCDIR "@TQTDOCDIR@"

==> tdewebdev-trinity-14.1.3.tar.xz: tdewebdev-trinity-14.1.3/config.h.cmake <==
#define VERSION "@VERSION@"

// Defined if you have fvisibility and fvisibility-inlines-hidden support.
#cmakedefine __TDE_HAVE_GCC_VISIBILITY 1

/* Define WORDS_BIGENDIAN to 1 if your processor stores words with the most
   significant byte first (like Motorola and SPARC, unlike Intel). */
#cmakedefine WORDS_BIGENDIAN @WORDS_BIGENDIAN@

/* Define to 1 if you have the <unistd.h> header file. */
#cmakedefine HAVE_UNISTD_H 1

/* Define to 1 if you have the <string.h> header file. */
#cmakedefine HAVE_STRING_H 1

/* Define to 1 if you have the <sys/time.h> header file. */
#cmakedefine HAVE_SYS_TIME_H 1

/* Define to 1 if you have the <sys/stat.h> header file. */
#cmakedefine HAVE_SYS_STAT_H 1

/* Define to 1 if you have the <stdlib.h> header file. */
#cmakedefine HAVE_STDLIB_H 1

/* Define to 1 if you have the <stdarg.h> header file. */
#cmakedefine HAVE_STDARG_H 1

/* Define to 1 if you have the <time.h> header file. */
#cmakedefine HAVE_TIME_H 1

/* Define to 1 if you have the <pthread.h> header file. */
#cmakedefine USE_XSLDBG_AS_THREAD 1

/* Define to 1 if you have the <locale.h> header file. */
//#cmakedefine LOCALE_PREFIX 1

/* Define to 1 if you have the <readline/readline.h> header file. */
#cmakedefine HAVE_READLINE @HAVE_READLINE@

/* Define to 1 if you have the 'gettimeofday' function */
#cmakedefine HAVE_GETTIMEOFDAY 1

/* Define to 1 if you have the 'usleep' function */
#cmakedefine HAVE_USLEEP 1

/* Define to 1 if you have the 'stat' function */
#cmakedefine HAVE_STAT 1

/* Define to 1 if you have the <readline/history.h> header file. */
#cmakedefine HAVE_HISTORY @HAVE_HISTORY@

/* Define the name of the xsldbg executable */
#cmakedefine XSLDBG_BIN "@XSLDBG_BIN@"

/* Defined if you build build for other editors than Kate */
#cmakedefine ENABLE_EDITORS 1

/* Defined if you build with cvsservice */
#cmakedefine ENABLE_CVSSERVICE 1

/* Defined if you build with enabled docbook input files */
#cmakedefine LIBXML_DOCB_ENABLED

/* Defined if you have <libxml/xinclude.h> header file */
#cmakedefine LIBXML_XINCLUDE_ENABLED

/* Define the kmdr-executor executable path */
#cmakedefine KMDR_EXECUTOR_PATH "@KMDR_EXECUTOR_PATH@"

/* Define TQTDOCDIR PATH */
#cmakedefine TQTDOCDIR "@TQTDOCDIR@"
